@@ -230,10 +230,10 @@ read_partDescriptor(int& shared)
 }
 
 int EIOMeshAgent::
-read_nextElementConnections(int& tag, int& body, int& type, int* pdofs, int* nodes )
+read_nextElementConnections(int& tag, int& part, int& body, int& type, int* pdofs, int* nodes )
 {
   int i, gotnodal;
-  char typestr[32];
+  char typestr[32], tagstr[32];
   fstream& str = meshFileStream[ELEMENTS];
   if(step == elementCount)
     {
@@ -241,9 +241,12 @@ read_nextElementConnections(int& tag, int& body, int& type, int* pdofs, int* nod
       step = 0;
       return -1;
     }
-  str >> tag >> body >> typestr ;
-  gotnodal = 0;
   for( i=0; i<6; i++ ) pdofs[i] = 0;
+  str >> tagstr >> body >> typestr ;
+  part = 0;
+  sscanf( tagstr, "%d/%d", &tag, &part );
+
+  gotnodal = 0;
   for( i=0; i<strlen(typestr); i++ )
   {
      switch( typestr[i] ) {
@@ -318,10 +321,11 @@ read_nextElementCoordinates(int& tag, int& body, int& type, int* nodes, double *
 
 
 int EIOMeshAgent::
-read_nextBoundaryElement(int& tag, int& boundary, int& leftElement,
+read_nextBoundaryElement(int& tag, int& part, int& boundary, int& leftElement,
                          int& rightElement, int& type, int* nodes, double* coord)
 {
   int i;
+  char tagstr[32];
   fstream& str = meshFileStream[BOUNDARY];
 
   if(step == boundaryElementCount)
@@ -335,7 +339,9 @@ read_nextBoundaryElement(int& tag, int& boundary, int& leftElement,
       cache_nodes();
     }
 
-  str >> tag >> boundary >> leftElement >> rightElement;
+  str >> tagstr >> boundary >> leftElement >> rightElement;
+  part = 0;
+  sscanf( tagstr, "%d/%d", &tag, &part );
 
   str >> type;
   int elNodes = elementNodes(type);
@@ -356,7 +362,7 @@ read_nextBoundaryElement(int& tag, int& boundary, int& leftElement,
       if(!ok)
 	{
 	  ++step;
-	  return read_nextBoundaryElement(tag, boundary, 
+	  return read_nextBoundaryElement(tag, part, boundary, 
 					  leftElement, rightElement, 
 					  type, nodes, coord);
 	}
