@@ -350,7 +350,8 @@ extern "C" void  eio_get_mesh_bndry_element
    int& type, int* nodes, double *coord,
    int& info)
 {
-  if(meshAgent->read_nextBoundaryElement(tag, boundary, 
+  int part;
+  if(meshAgent->read_nextBoundaryElement(tag, part, boundary, 
 					 leftElement, rightElement, 
 					 type, nodes, coord) != -1)
     info = 0;
@@ -373,7 +374,8 @@ extern "C" void  eio_get_mesh_element_conns
   (int& tag, int& body, int& type, int *pdofs, int *nodes, 
    int& info)
 {
-  if(meshAgent->read_nextElementConnections(tag, body, type, pdofs, nodes) != -1)
+  int part;
+  if(meshAgent->read_nextElementConnections(tag, part, body, type, pdofs, nodes) != -1)
     info = 0;
   else info = -1;
 }
